@@ -3,43 +3,32 @@
 
 #pragma once
 
-#include <QAbstractListModel>
-#include <QDateTime>
+#include "abstractinstancesmodel.h"
+
 #include <QNetworkAccessManager>
-#include <QUrl>
 #include <QtQml>
 
-class InvidiousInstancesModel : public QAbstractListModel
+class InvidiousInstancesModel : public AbstractInstancesModel
 {
     Q_OBJECT
     QML_ELEMENT
 
-    Q_PROPERTY(bool loading READ loading NOTIFY loadingChanged)
-
 public:
-    enum CustomRoles { URLRole = Qt::UserRole };
-
     explicit InvidiousInstancesModel(QObject *parent = nullptr);
 
-    bool loading() const;
-    void setLoading(bool loading);
-
     QVariant data(const QModelIndex &index, int role) const override;
     int rowCount(const QModelIndex &parent) const override;
-    QHash<int, QByteArray> roleNames() const override;
-
-Q_SIGNALS:
-    void loadingChanged();
 
 private:
     void fill();
 
     struct InvidiousInstance {
+        QString name;
         QString url;
+        QString region;
     };
 
     QList<InvidiousInstance> m_instances;
-    bool m_loading = false;
     InvidiousInstance fromSourceData(const QJsonArray &object) const;
     QNetworkAccessManager m_netManager;
 };
